Re: [PATCH] Use a hashtable for objects instead of a sorted list
- From
- Alexandre Julliard <julliard@winehq.org>
- Date
- Feb 12, 2006, 08:52 UTC
- Message-ID
- <87oe1dez7k.fsf@wine.dyndns.org>
- In-Reply-To
- <7virrli9am.fsf@assigned-by-dhcp.cox.net>
Junio C Hamano <junkio@cox.net> writes:
Show 5 quoted lines
> I am also interested to find out how much the rehashing you do > when you update obj_allocs to a larger value is costing. > > Alexandle, if you have a chance, could you try Johannes' patch > on your workload to see if it works OK for you?
It works great for me, CPU time is down to 15 sec instead of 20 sec with my patch.
-- Alexandre Julliard julliard@winehq.org